#!/bin/env python
#----------------------------------------------------------------------
# A very simple wxPython example.  Just a wxFrame, wxPanel,
# wxStaticText, wxButton, and a wxBoxSizer, but it shows the basic
# structure of any wxPython application.
#----------------------------------------------------------------------

import os, sys, time, string, pprint, copy

import wx
import wx.html

from mixCore import *
from chwin import *
from mnwin import *
from sysenv import *
from wxPython.wx import *
from wxPython.help import *
from wxPython.lib.anchors import LayoutAnchors
from wxPython.stc import *

def opj(path):
    """Convert paths to the platform-specific separator"""
    return apply(os.path.join, tuple(path.split('/')))

chwindow = []

class MyFrame(wx.Frame):
    def __init__(self, parent, title):
        global	frameSize
        global  chvwin

        # initialize my frame
        wx.Frame.__init__(self, parent, -1, title, size=(0,0),pos=(30,30))
        #wx.LogNull()

        # Create the menubar
        menuBar = wx.MenuBar()

        # Create a menu 
        fmenu = wx.Menu()
        fmenu.Append(wx.ID_EXIT, "L&oad\tCtrl-L", "Load Setting")
        fmenu.Append(wx.ID_EXIT, "S&ave\tCtrl-S", "Save Setting")
        fmenu.Append(wx.ID_EXIT, "S&ave as\tCtrl-s", "Save Setting as...")
        fmenu.Append(800, "P&ropaty\tCtrl-p", "Propaty")
        fmenu.Append(wx.ID_EXIT, "E&xit\tAlt-X", "Exit k-mix")
        emenu = wx.Menu()
        emenu.Append(wx.ID_EXIT, "C&opy\tCtrl-c", "Copy")
        emenu.Append(wx.ID_EXIT, "C&ut\tCtrl-C", "Cut")
        emenu.Append(wx.ID_EXIT, "P&ast\tCtrl-P", "Past")

        # bind the menu event to an event handler
        self.Bind(wx.EVT_MENU, self.OnTimeToClose, id=wx.ID_EXIT)
        self.Bind(wx.EVT_MENU, self.SetSystem, id=800);

        # and put the menu on the menubar
        menuBar.Append(fmenu, "&File")
        menuBar.Append(emenu, "&Edit")
        self.SetMenuBar(menuBar)
        self.CreateStatusBar()

        # Now create the Panel to put the other controls on.
        panel = wx.Panel(self)
        chvwin = chNotePanel(panel, comctrl, chctrl)
        self.mnwin = mainControlPanel(panel, comctrl, mnctrl, chwindow)
        sizer = wx.BoxSizer(wx.HORIZONTAL)
        sizer.Add(chvwin, 0, wx.ALL, 0)
        sizer.Add(self.mnwin, 0, wx.ALL, 0)
        panel.SetSizer(sizer)
        panel.Layout()
        panel.Fit()
        frameSize = self.GetSize()
        size = (chvwin.winsize.width + self.mnwin.winsize.width + 8,
                chvwin.winsize.height + frameSize.height + 36)
        self.SetSize(size)
        self.timer = mixerConnectCheck()

    def OnTimeToClose(self, evt):
        """Event handler for the button click."""
        self.Close()

    def SetSystem(self, evt):
        global sysctrl

        win = mixSysEnv(self, -1, sysctrl)
        #win.CenterOnScreen()
        val = win.ShowModal()
        #if val == wx.ID_OK:
        #    sysctrl.progSysEnv(1)	# set
        #else:
        #    sysctrl.progSysEnv(0)	# cancel
        #win.Destroy()

class MyApp(wx.App):
    def OnInit(self):
        global comctrl
        global mnctrl
        global chctrl
        global sysctrl

        #wx.Log_SetActiveTarget(wx.LogPassThrough(self.log))
        wx.LogNull()
        wx.InitAllImageHandlers()
        splash = MySplashScreen()
        splash.Show()
        self.comctrl = mixerCom()
        self.mnctrl  = mainCtrl()
        self.chctrl  = chCtrl()
        self.sysctrl = sysCtrl()
        mnctrl  = self.mnctrl
        chctrl  = self.chctrl
        comctrl = self.comctrl
        sysctrl = self.sysctrl
        return True

    def OnRun(self):
        self.OnRun()

class MySplashScreen(wx.SplashScreen):
    def __init__(self):
        bmp = wx.Image(opj("image/StartDialog.bmp")).ConvertToBitmap()
        wx.SplashScreen.__init__(self, bmp,
               wx.SPLASH_CENTRE_ON_SCREEN | wx.SPLASH_TIMEOUT,
               1000, None, -1)
        self.Bind(wx.EVT_CLOSE, self.OnClose)

    def OnClose(self, evt):
        self.Hide()
        self.frame = MyFrame(None, "K-mixer")
        self.frame.Show(True)
        evt.Skip()  # Make sure the default handler runs too...

#----------------------------------------------------------------------#
#    CH control top Note panel                                         #
#----------------------------------------------------------------------#
class chNotePanel(wx.Notebook):
    def __init__(self, parent, com, chctrl):
        global chwinSize

        wx.Notebook.__init__(self, parent, -1,
                             style=wx.NB_TOP|wx.NB_FIXEDWIDTH)
        nbs = wx.NotebookSizer(self)
        chlist = []
        for i in range(4):
            win = chFrame(self, com, chctrl, i)
            chlist.append(win)
        #self.SetPageSize(chwinSize)
        self.AddPage(chlist[0], "CH1-4")
        self.AddPage(chlist[1], "CH5-8")
        self.AddPage(chlist[2], "CH9-12")
        self.AddPage(chlist[3], "CH13-16")
        nbs.Add(chlist[0], 0, wx.ALL, 0)
        nbs.Add(chlist[1], 0, wx.ALL, 0)
        nbs.Add(chlist[2], 0, wx.ALL, 0)
        nbs.Add(chlist[3], 0, wx.ALL, 0)
        #self.Bind(wx.EVT_NOTEBOOK_PAGE_CHANGED, self.OnPageChanged)
        #self.Bind(wx.EVT_NOTEBOOK_PAGE_CHANGING, self.OnPageChanging)
        self.SetAutoLayout(True)
        self.SetSizer(nbs)
        self.Fit()
        self.winsize = self.GetSize()

#----------------------------------------------------------------------#
#    CH control top panel for 4ch                                      #
#----------------------------------------------------------------------#
class chFrame(wx.Panel):
    def __init__(self, parent, com, chctrl, grp):
        global mixcom
        global chdata
        global chwinSize
        global chwindow

        chdata = chctrl
        mixcom = com

        p = wx.Panel.__init__(self, parent, -1, style=wx.STATIC_BORDER)
        chwin = []
        for i in range(4):
            win = chControlPanel(self, com, chctrl, i+4*grp)
            chwin.append(win)
            chwindow.append(win)
        chframe = wx.BoxSizer(wx.HORIZONTAL)
        chframe.Add(chwin[0], 0, wx.ALL, 0)
        chframe.Add(chwin[1], 0, wx.ALL, 0)
        chframe.Add(chwin[2], 0, wx.ALL, 0)
        chframe.Add(chwin[3], 0, wx.ALL, 0)

        self.SetAutoLayout(True)
        self.SetSizer(chframe)
        chframe.Fit(self)

        #### size of CH Frame ####
        chwinSize = self.GetSize()

        #def OnCPSize(evt, win=chframe):
        #    self.SetSize(evt.GetSize())
        # 
        #self.Bind(wx.EVT_SIZE, OnCPSize)

wx.LogNull()
app = MyApp()
app.MainLoop()
#endif

